@@ -1,12 +1,16 @@
 # flake8: noqa
 
-from stactools.core.io import use_fsspec
-from stactools.core.copy import (move_asset_file_to_item, move_assets,
-                                 move_all_assets, copy_catalog)
-from stactools.core.layout import layout_catalog
-from stactools.core.merge import (merge_items, merge_all_items)
 from stactools.core.add import add_item
 from stactools.core.addraster import add_raster_to_item
+from stactools.core.copy import (
+    copy_catalog,
+    move_all_assets,
+    move_asset_file_to_item,
+    move_assets,
+)
+from stactools.core.io import use_fsspec
+from stactools.core.layout import layout_catalog
+from stactools.core.merge import merge_all_items, merge_items
 
 __all__ = [
     "add_item",
@@ -20,4 +24,4 @@ __all__ = [
     "move_all_assets",
     "use_fsspec",
 ]
-__version__ = "0.2.6"
+__version__ = "0.3.1"
