@@ -1,7 +1,9 @@
-from typing import Callable, Optional, Any
+from typing import Any, Callable, Optional
 
-from pystac.stac_io import DefaultStacIO, StacIO
 import fsspec
+from pystac.stac_io import DefaultStacIO, StacIO
+
+from stactools.core import utils
 
 ReadHrefModifier = Callable[[str], str]
 """Type alias for a function parameter
@@ -11,8 +13,7 @@ to a signed URL
 """
 
 
-def read_text(href: str,
-              read_href_modifier: Optional[ReadHrefModifier] = None) -> str:
+def read_text(href: str, read_href_modifier: Optional[ReadHrefModifier] = None) -> str:
     if read_href_modifier is None:
         return StacIO.default().read_text(href)
     else:
@@ -20,20 +21,28 @@ def read_text(href: str,
 
 
 class FsspecStacIO(DefaultStacIO):
-
     def read_text_from_href(self, href: str, *args: Any, **kwargs: Any) -> str:
         with fsspec.open(href, "r") as f:
             s = f.read()
             if isinstance(s, str):
                 return s
             elif isinstance(s, bytes):
-                return str(s, encoding='utf-8')
+                return str(s, encoding="utf-8")
             else:
-                raise ValueError(
-                    f"Unable to decode data loaded from HREF: {href}")
+                raise ValueError(f"Unable to decode data loaded from HREF: {href}")
 
-    def write_text_from_href(self, href: str, txt: str, *args: Any,
-                             **kwargs: Any) -> None:
+    def write_text_from_href(
+        self, href: str, txt: str, *args: Any, **kwargs: Any
+    ) -> None:
+        utils.deprecate(
+            "FsspecStacIO.write_text_from_href",
+            "FsspecStacIO.write_text_to_href",
+            "v0.5.0",
+        )
+        return self.write_text_to_href(href, txt)
+
+    def write_text_to_href(self, href: str, txt: str) -> None:
+        """Writes text to an href using fsspec."""
         with fsspec.open(href, "w") as destination:
             destination.write(txt)
 
