@@ -1,10 +1,11 @@
+import warnings
 from typing import Callable, Optional, TypeVar
 
 import fsspec
 import rasterio
 
-T = TypeVar('T')
-U = TypeVar('U')
+T = TypeVar("T")
+U = TypeVar("U")
 
 
 def map_opt(fn: Callable[[T], U], v: Optional[T]) -> Optional[U]:
@@ -28,3 +29,12 @@ def gdal_driver_is_enabled(name: str) -> bool:
     """Checks to see if the named GDAL driver is enabled."""
     with rasterio.Env() as env:
         return name in env.drivers().keys()
+
+
+def deprecate(from_: str, to: str, version: str) -> None:
+    """Warn with DeprecationWarning and a pre-canned message."""
+    warnings.warn(
+        f"{from_} is deprecated and will be removed in {version}. Use {to} instead.",
+        DeprecationWarning,
+        stacklevel=2,
+    )
