@@ -1,27 +1,25 @@
-from abc import (ABC, abstractmethod)
 import logging
-from typing import List, Callable
 import unittest
+from abc import ABC, abstractmethod
+from typing import Callable, List
 
 import click
 from click.testing import CliRunner, Result
 
 
 class CliTestCase(unittest.TestCase, ABC):
-
     def use_debug_logging(self) -> None:
-        logger = logging.getLogger('stactools')
+        logger = logging.getLogger("stactools")
         logger.setLevel(logging.DEBUG)
 
         ch = logging.StreamHandler()
         ch.setLevel(logging.DEBUG)
-        formatter = logging.Formatter('%(message)s')
+        formatter = logging.Formatter("%(message)s")
         ch.setFormatter(formatter)
 
         logger.addHandler(ch)
 
     def setUp(self) -> None:
-
         @click.group()
         def cli() -> None:
             pass
@@ -39,6 +37,7 @@ class CliTestCase(unittest.TestCase, ABC):
 
     @abstractmethod
     def create_subcommand_functions(
-            self) -> List[Callable[[click.Group], click.Command]]:
+        self,
+    ) -> List[Callable[[click.Group], click.Command]]:
         """Return list of 'create_command' functions from implementations"""
         pass
